OC.L10N.register(
    "templateeditor",
    {
    "Could not load template" : "Αδυναμία φόρτωσης προτύπου",
    "Saved" : "Αποθηκεύτηκαν",
    "Reset" : "Επαναφορά",
    "An error occurred" : "Παρουσιάστηκε σφάλμα",
    "Sharing email - public link shares (HTML)" : "Διαμοιρασμός ηλεκτρονικού ταχυδρομείου - διαμοιρασμός δημόσιων συνδέσμων (HTML)",
    "Sharing email - public link shares (plain text fallback)" : "Διαμοιρασμός ηλεκτρονικού ταχυδρομείου - διαμοιρασμός δημόσιων συνδέσμων (εναλλακτική απλού κειμένου)",
    "Sharing email (HTML)" : "Διαμοιρασμός ηλεκτρονικού ταχυδρομείου (HTML)",
    "Sharing email (plain text fallback)" : "Διαμοιρασμός ηλεκτρονικού ταχυδρομείου (εφεδρικό απλού κειμένου)",
    "Lost password mail" : "Μήνυμα χαμένου κωδικού πρόσβασης",
    "New user email (HTML)" : "Διεύθυνση νέου χρήστη (HTML)",
    "New user email (plain text fallback)" : "Ηλεκτρονικό ταχυδρομείο νέου χρήστη (εφεδρικό απλό κείμενο)",
    "Activity notification mail" : "Μήνυμα ειδοποίησης δραστηριότητας",
    "Mail Templates" : "Πρότυπα αλληλογραφίας",
    "Theme" : "Θέμα",
    "Template" : "Πρότυπο",
    "Please choose a template" : "Παρακαλώ επιλέξτε ένα πρότυπο",
    "Save" : "Αποθήκευση"
},
"nplurals=2; plural=(n != 1);");
